#!/usr/bin/python

import datetime
import logging
import os
import sys

from launchpadlib.launchpad import Launchpad

SERVICE_ROOT = 'edge'

# get all uploads (including all distro series and all pockets)
# for this distribution since a given date
DISTRIBUTION = "ubuntu"


class LaunchpadChangelogsCrawler(object):
    """ a crawler that can find out about changed packages in LP """

    # LP service name (free form)
    SERVICE_NAME = 'get_changelogs anoymously'

    # local dir layout
    ROOT = os.getcwd()
    CREDENTIALS_FILE = os.path.join(ROOT, "lp-credential.txt")

    def __init__(self, targetdir="./changelogs"):
        self.lp_cachedir = os.path.abspath(os.path.join(self.ROOT,
                                                        "lp-cache/"))
        self._launchpad = None

    def login_anoymously(self):
        self._launchpad = Launchpad.login_anonymously(self.SERVICE_NAME,
                                                      SERVICE_ROOT,
                                                      self.lp_cachedir)

    def login_interactive(self):
        service = SERVICE_ROOT
        self._launchpad = Launchpad.get_token_and_login(self.SERVICE_NAME,
                                                        service,
                                                        self.lp_cachedir)

        with open(self.CREDENTIALS_FILE, "w+") as fd:
            self._launchpad.credentials.save(fd)

    def get_changelogs_since(self, date):
        ubuntu = self._launchpad.distributions[DISTRIBUTION]
        archive = ubuntu.main_archive
        changed = archive.getPublishedSources(created_since_date=date)
        for source in changed:
            print(source.source_package_name, source.date_published,
                  source.status)

if __name__ == "__main__":
    if not len(sys.argv) > 1:
        print("need hh:mm yyyy-mm-dd argument")
        sys.exit(1)

    logging.basicConfig(level=logging.DEBUG)
    c = LaunchpadChangelogsCrawler()
    c.login_anoymously()
    date = datetime.datetime.strptime(sys.argv[1], "%H:%M %Y-%m-%d")
    c.get_changelogs_since(date)
